import os
from datetime import datetime
import pytest
from freezegun import freeze_time

# Use a consistent timestamp for all tests: 2025-01-31 12:00:00 UTC
TEST_TIME = "2025-01-31 12:00:00"
TEST_TIMESTAMP = int(datetime.fromisoformat(TEST_TIME).timestamp())


@pytest.fixture
def test_dir(tmp_path):
    """Create a test directory with various files and subdirectories."""
    with freeze_time(TEST_TIME):
        # Create files with consistent timestamps
        files = [
            "file1.txt",
            "file2.txt",
            ".hidden.txt",
            "script.py",
        ]

        # Create all main files
        for filename in files:
            path = tmp_path / filename
            path.write_text(f"Content of {filename}")
            os.utime(path, (TEST_TIMESTAMP, TEST_TIMESTAMP))

        # Create subdirectory FIRST and set its timestamp IMMEDIATELY
        subdir = tmp_path / "subdir"
        subdir.mkdir()
        os.utime(
            subdir, (TEST_TIMESTAMP, TEST_TIMESTAMP)
        )  # Set timestamp right after creation

        # Then create files in subdirectory
        subdir_files = [
            "subfile1.txt",
            "subfile2.py",
        ]

        for filename in subdir_files:
            path = subdir / filename
            path.write_text(f"Content of {filename}")
            os.utime(path, (TEST_TIMESTAMP, TEST_TIMESTAMP))
    return subdir



import pytest
from freezegun import freeze_time
from inline_snapshot import snapshot
from pols import pols


@pytest.mark.xfail(reason="Symlink handling not implemented yet")
@freeze_time("2025-01-31 12:00:00")
def test_symlink_follow(test_dir):
    """Test following symlinks."""
    result = pols(test_dir, L=True)
    assert str(result) == snapshot()



from __future__ import annotations

import polars as pl


def make_size_human_readable(files: pl.DataFrame) -> pl.DataFrame:
    size_col = pl.col("size")
    return files.with_columns(
        size=pl.when(size_col < 1024)
        .then(pl.concat_str(size_col.cast(pl.String), pl.lit("")))
        .when(size_col < 1024 * 1024)
        .then(
            pl.concat_str(size_col.truediv(1024).round(1).cast(pl.String), pl.lit("K"))
        )
        .when(size_col < 1024 * 1024 * 1024)
        .then(
            pl.concat_str(
                size_col.truediv(1024 * 1024).round(0).cast(pl.String), pl.lit("M")
            )
        )
        .otherwise(
            pl.concat_str(
                size_col.truediv(1024 * 1024 * 1024).round(0).cast(pl.String),
                pl.lit("G"),
            )
        )
    )



from __future__ import annotations

import polars as pl


def add_size_metadata(files: pl.DataFrame) -> pl.DataFrame:
    size_column = [p.stat().st_size for p in files.get_column("path")]
    return files.with_columns(size=pl.Series(size_column))
